package android.support.v7.widget;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.content.pm.PackageManager;
import android.content.pm.ResolveInfo;
import android.database.DataSetObservable;
import android.os.AsyncTask;
import android.support.v4.os.AsyncTaskCompat;
import android.text.TextUtils;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

class ActivityChooserModel
  extends DataSetObservable
{
  private static final String ATTRIBUTE_ACTIVITY = "activity";
  private static final String ATTRIBUTE_TIME = "time";
  private static final String ATTRIBUTE_WEIGHT = "weight";
  private static final boolean DEBUG = false;
  private static final int DEFAULT_ACTIVITY_INFLATION = 5;
  private static final float DEFAULT_HISTORICAL_RECORD_WEIGHT = 1.0F;
  public static final String DEFAULT_HISTORY_FILE_NAME = "activity_choser_model_history.xml";
  public static final int DEFAULT_HISTORY_MAX_LENGTH = 50;
  private static final String HISTORY_FILE_EXTENSION = ".xml";
  private static final int INVALID_INDEX = -1;
  private static final String LOG_TAG = ActivityChooserModel.class.getSimpleName();
  private static final String TAG_HISTORICAL_RECORD = "historical-record";
  private static final String TAG_HISTORICAL_RECORDS = "historical-records";
  private static final Map<String, ActivityChooserModel> sDataModelRegistry = new HashMap();
  private static final Object sRegistryLock = new Object();
  private final List<ActivityResolveInfo> mActivities = new ArrayList();
  private OnChooseActivityListener mActivityChoserModelPolicy;
  private ActivitySorter mActivitySorter = new DefaultSorter(null);
  private boolean mCanReadHistoricalData = true;
  private final Context mContext;
  private final List<HistoricalRecord> mHistoricalRecords = new ArrayList();
  private boolean mHistoricalRecordsChanged = true;
  private final String mHistoryFileName;
  private int mHistoryMaxSize = 50;
  private final Object mInstanceLock = new Object();
  private Intent mIntent;
  private boolean mReadShareHistoryCalled = false;
  private boolean mReloadActivities = false;
  
  private ActivityChooserModel(Context paramContext, String paramString)
  {
    this.mContext = paramContext.getApplicationContext();
    if ((!TextUtils.isEmpty(paramString)) && (!paramString.endsWith(".xml")))
    {
      this.mHistoryFileName = (paramString + ".xml");
      return;
    }
    this.mHistoryFileName = paramString;
  }
  
  private boolean addHisoricalRecord(HistoricalRecord paramHistoricalRecord)
  {
    boolean bool = this.mHistoricalRecords.add(paramHistoricalRecord);
    if (bool)
    {
      this.mHistoricalRecordsChanged = true;
      pruneExcessiveHistoricalRecordsIfNeeded();
      persistHistoricalDataIfNeeded();
      sortActivitiesIfNeeded();
      notifyChanged();
    }
    return bool;
  }
  
  private void ensureConsistentState()
  {
    boolean bool1 = loadActivitiesIfNeeded();
    boolean bool2 = readHistoricalDataIfNeeded();
    pruneExcessiveHistoricalRecordsIfNeeded();
    if ((bool1 | bool2))
    {
      sortActivitiesIfNeeded();
      notifyChanged();
    }
  }
  
  public static ActivityChooserModel get(Context paramContext, String paramString)
  {
    synchronized (sRegistryLock)
    {
      ActivityChooserModel localActivityChooserModel2 = (ActivityChooserModel)sDataModelRegistry.get(paramString);
      ActivityChooserModel localActivityChooserModel1 = localActivityChooserModel2;
      if (localActivityChooserModel2 == null)
      {
        localActivityChooserModel1 = new ActivityChooserModel(paramContext, paramString);
        sDataModelRegistry.put(paramString, localActivityChooserModel1);
      }
      return localActivityChooserModel1;
    }
  }
  
  private boolean loadActivitiesIfNeeded()
  {
    if ((this.mReloadActivities) && (this.mIntent != null))
    {
      this.mReloadActivities = false;
      this.mActivities.clear();
      List localList = this.mContext.getPackageManager().queryIntentActivities(this.mIntent, 0);
      int j = localList.size();
      int i = 0;
      while (i < j)
      {
        ResolveInfo localResolveInfo = (ResolveInfo)localList.get(i);
        this.mActivities.add(new ActivityResolveInfo(localResolveInfo));
        i += 1;
      }
      return true;
    }
    return false;
  }
  
  private void persistHistoricalDataIfNeeded()
  {
    if (!this.mReadShareHistoryCalled) {
      throw new IllegalStateException("No preceding call to #readHistoricalData");
    }
    if (!this.mHistoricalRecordsChanged) {
      return;
    }
    this.mHistoricalRecordsChanged = false;
    if (!TextUtils.isEmpty(this.mHistoryFileName)) {
      AsyncTaskCompat.executeParallel(new PersistHistoryAsyncTask(null), new Object[] { new ArrayList(this.mHistoricalRecords), this.mHistoryFileName });
    }
  }
  
  private void pruneExcessiveHistoricalRecordsIfNeeded()
  {
    int j = this.mHistoricalRecords.size() - this.mHistoryMaxSize;
    if (j <= 0) {
      return;
    }
    this.mHistoricalRecordsChanged = true;
    int i = 0;
    while (i < j)
    {
      HistoricalRecord localHistoricalRecord = (HistoricalRecord)this.mHistoricalRecords.remove(0);
      i += 1;
    }
  }
  
  private boolean readHistoricalDataIfNeeded()
  {
    if ((this.mCanReadHistoricalData) && (this.mHistoricalRecordsChanged) && (!TextUtils.isEmpty(this.mHistoryFileName)))
    {
      this.mCanReadHistoricalData = false;
      this.mReadShareHistoryCalled = true;
      readHistoricalDataImpl();
      return true;
    }
    return false;
  }
  
  /* Error */
  private void readHistoricalDataImpl()
  {
    // Byte code:
    //   0: aload_0
    //   1: getfield 145	android/support/v7/widget/ActivityChooserModel:mContext	Landroid/content/Context;
    //   4: aload_0
    //   5: getfield 169	android/support/v7/widget/ActivityChooserModel:mHistoryFileName	Ljava/lang/String;
    //   8: invokevirtual 277	android/content/Context:openFileInput	(Ljava/lang/String;)Ljava/io/FileInputStream;
    //   11: astore_2
    //   12: invokestatic 283	android/util/Xml:newPullParser	()Lorg/xmlpull/v1/XmlPullParser;
    //   15: astore_3
    //   16: aload_3
    //   17: aload_2
    //   18: ldc_w 285
    //   21: invokeinterface 291 3 0
    //   26: iconst_0
    //   27: istore_1
    //   28: iload_1
    //   29: iconst_1
    //   30: if_icmpeq +18 -> 48
    //   33: iload_1
    //   34: iconst_2
    //   35: if_icmpeq +13 -> 48
    //   38: aload_3
    //   39: invokeinterface 294 1 0
    //   44: istore_1
    //   45: goto -17 -> 28
    //   48: ldc 63
    //   50: aload_3
    //   51: invokeinterface 297 1 0
    //   56: invokevirtual 300	java/lang/String:equals	(Ljava/lang/Object;)Z
    //   59: ifne +55 -> 114
    //   62: new 271	org/xmlpull/v1/XmlPullParserException
    //   65: dup
    //   66: ldc_w 302
    //   69: invokespecial 303	org/xmlpull/v1/XmlPullParserException:<init>	(Ljava/lang/String;)V
    //   72: athrow
    //   73: astore_3
    //   74: getstatic 98	android/support/v7/widget/ActivityChooserModel:LOG_TAG	Ljava/lang/String;
    //   77: new 159	java/lang/StringBuilder
    //   80: dup
    //   81: invokespecial 160	java/lang/StringBuilder:<init>	()V
    //   84: ldc_w 305
    //   87: invokevirtual 164	java/lang/StringBuilder:append	(Ljava/lang/String;)Ljava/lang/StringBuilder;
    //   90: aload_0
    //   91: getfield 169	android/support/v7/widget/ActivityChooserModel:mHistoryFileName	Ljava/lang/String;
    //   94: invokevirtual 164	java/lang/StringBuilder:append	(Ljava/lang/String;)Ljava/lang/StringBuilder;
    //   97: invokevirtual 167	java/lang/StringBuilder:toString	()Ljava/lang/String;
    //   100: aload_3
    //   101: invokestatic 311	android/util/Log:e	(Ljava/lang/String;Ljava/lang/String;Ljava/lang/Throwable;)I
    //   104: pop
    //   105: aload_2
    //   106: ifnull +7 -> 113
    //   109: aload_2
    //   110: invokevirtual 316	java/io/FileInputStream:close	()V
    //   113: return
    //   114: aload_0
    //   115: getfield 122	android/support/v7/widget/ActivityChooserModel:mHistoricalRecords	Ljava/util/List;
    //   118: astore 4
    //   120: aload 4
    //   122: invokeinterface 222 1 0
    //   127: aload_3
    //   128: invokeinterface 294 1 0
    //   133: istore_1
    //   134: iload_1
    //   135: iconst_1
    //   136: if_icmpne +12 -> 148
    //   139: aload_2
    //   140: ifnull -27 -> 113
    //   143: aload_2
    //   144: invokevirtual 316	java/io/FileInputStream:close	()V
    //   147: return
    //   148: iload_1
    //   149: iconst_3
    //   150: if_icmpeq -23 -> 127
    //   153: iload_1
    //   154: iconst_4
    //   155: if_icmpne +6 -> 161
    //   158: goto -31 -> 127
    //   161: ldc 60
    //   163: aload_3
    //   164: invokeinterface 297 1 0
    //   169: invokevirtual 300	java/lang/String:equals	(Ljava/lang/Object;)Z
    //   172: ifne +55 -> 227
    //   175: new 271	org/xmlpull/v1/XmlPullParserException
    //   178: dup
    //   179: ldc_w 318
    //   182: invokespecial 303	org/xmlpull/v1/XmlPullParserException:<init>	(Ljava/lang/String;)V
    //   185: athrow
    //   186: astore_3
    //   187: getstatic 98	android/support/v7/widget/ActivityChooserModel:LOG_TAG	Ljava/lang/String;
    //   190: new 159	java/lang/StringBuilder
    //   193: dup
    //   194: invokespecial 160	java/lang/StringBuilder:<init>	()V
    //   197: ldc_w 305
    //   200: invokevirtual 164	java/lang/StringBuilder:append	(Ljava/lang/String;)Ljava/lang/StringBuilder;
    //   203: aload_0
    //   204: getfield 169	android/support/v7/widget/ActivityChooserModel:mHistoryFileName	Ljava/lang/String;
    //   207: invokevirtual 164	java/lang/StringBuilder:append	(Ljava/lang/String;)Ljava/lang/StringBuilder;
    //   210: invokevirtual 167	java/lang/StringBuilder:toString	()Ljava/lang/String;
    //   213: aload_3
    //   214: invokestatic 311	android/util/Log:e	(Ljava/lang/String;Ljava/lang/String;Ljava/lang/Throwable;)I
    //   217: pop
    //   218: aload_2
    //   219: ifnull -106 -> 113
    //   222: aload_2
    //   223: invokevirtual 316	java/io/FileInputStream:close	()V
    //   226: return
    //   227: aload 4
    //   229: new 20	android/support/v7/widget/ActivityChooserModel$HistoricalRecord
    //   232: dup
    //   233: aload_3
    //   234: aconst_null
    //   235: ldc 31
    //   237: invokeinterface 322 3 0
    //   242: aload_3
    //   243: aconst_null
    //   244: ldc 34
    //   246: invokeinterface 322 3 0
    //   251: invokestatic 328	java/lang/Long:parseLong	(Ljava/lang/String;)J
    //   254: aload_3
    //   255: aconst_null
    //   256: ldc 37
    //   258: invokeinterface 322 3 0
    //   263: invokestatic 334	java/lang/Float:parseFloat	(Ljava/lang/String;)F
    //   266: invokespecial 337	android/support/v7/widget/ActivityChooserModel$HistoricalRecord:<init>	(Ljava/lang/String;JF)V
    //   269: invokeinterface 184 2 0
    //   274: pop
    //   275: goto -148 -> 127
    //   278: astore_2
    //   279: return
    //   280: astore_2
    //   281: return
    //   282: astore_2
    //   283: return
    //   284: astore_3
    //   285: aload_2
    //   286: ifnull +7 -> 293
    //   289: aload_2
    //   290: invokevirtual 316	java/io/FileInputStream:close	()V
    //   293: aload_3
    //   294: athrow
    //   295: astore_2
    //   296: goto -3 -> 293
    //   299: astore_2
    //   300: return
    // Local variable table:
    //   start	length	slot	name	signature
    //   0	301	0	this	ActivityChooserModel
    //   27	129	1	i	int
    //   11	212	2	localFileInputStream	java.io.FileInputStream
    //   278	1	2	localIOException1	java.io.IOException
    //   280	1	2	localIOException2	java.io.IOException
    //   282	8	2	localIOException3	java.io.IOException
    //   295	1	2	localIOException4	java.io.IOException
    //   299	1	2	localFileNotFoundException	java.io.FileNotFoundException
    //   15	36	3	localXmlPullParser	org.xmlpull.v1.XmlPullParser
    //   73	91	3	localXmlPullParserException	org.xmlpull.v1.XmlPullParserException
    //   186	69	3	localIOException5	java.io.IOException
    //   284	10	3	localObject	Object
    //   118	110	4	localList	List
    // Exception table:
    //   from	to	target	type
    //   12	26	73	org/xmlpull/v1/XmlPullParserException
    //   38	45	73	org/xmlpull/v1/XmlPullParserException
    //   48	73	73	org/xmlpull/v1/XmlPullParserException
    //   114	127	73	org/xmlpull/v1/XmlPullParserException
    //   127	134	73	org/xmlpull/v1/XmlPullParserException
    //   161	186	73	org/xmlpull/v1/XmlPullParserException
    //   227	275	73	org/xmlpull/v1/XmlPullParserException
    //   12	26	186	java/io/IOException
    //   38	45	186	java/io/IOException
    //   48	73	186	java/io/IOException
    //   114	127	186	java/io/IOException
    //   127	134	186	java/io/IOException
    //   161	186	186	java/io/IOException
    //   227	275	186	java/io/IOException
    //   143	147	278	java/io/IOException
    //   109	113	280	java/io/IOException
    //   222	226	282	java/io/IOException
    //   12	26	284	finally
    //   38	45	284	finally
    //   48	73	284	finally
    //   74	105	284	finally
    //   114	127	284	finally
    //   127	134	284	finally
    //   161	186	284	finally
    //   187	218	284	finally
    //   227	275	284	finally
    //   289	293	295	java/io/IOException
    //   0	12	299	java/io/FileNotFoundException
  }
  
  private boolean sortActivitiesIfNeeded()
  {
    if ((this.mActivitySorter != null) && (this.mIntent != null) && (!this.mActivities.isEmpty()) && (!this.mHistoricalRecords.isEmpty()))
    {
      this.mActivitySorter.sort(this.mIntent, this.mActivities, Collections.unmodifiableList(this.mHistoricalRecords));
      return true;
    }
    return false;
  }
  
  public Intent chooseActivity(int paramInt)
  {
    synchronized (this.mInstanceLock)
    {
      if (this.mIntent == null) {
        return null;
      }
      ensureConsistentState();
      Object localObject2 = (ActivityResolveInfo)this.mActivities.get(paramInt);
      localObject2 = new ComponentName(((ActivityResolveInfo)localObject2).resolveInfo.activityInfo.packageName, ((ActivityResolveInfo)localObject2).resolveInfo.activityInfo.name);
      Intent localIntent1 = new Intent(this.mIntent);
      localIntent1.setComponent((ComponentName)localObject2);
      if (this.mActivityChoserModelPolicy != null)
      {
        Intent localIntent2 = new Intent(localIntent1);
        if (this.mActivityChoserModelPolicy.onChooseActivity(this, localIntent2)) {
          return null;
        }
      }
      addHisoricalRecord(new HistoricalRecord((ComponentName)localObject2, System.currentTimeMillis(), 1.0F));
      return localIntent1;
    }
  }
  
  public ResolveInfo getActivity(int paramInt)
  {
    synchronized (this.mInstanceLock)
    {
      ensureConsistentState();
      ResolveInfo localResolveInfo = ((ActivityResolveInfo)this.mActivities.get(paramInt)).resolveInfo;
      return localResolveInfo;
    }
  }
  
  public int getActivityCount()
  {
    synchronized (this.mInstanceLock)
    {
      ensureConsistentState();
      int i = this.mActivities.size();
      return i;
    }
  }
  
  public int getActivityIndex(ResolveInfo paramResolveInfo)
  {
    for (;;)
    {
      int i;
      synchronized (this.mInstanceLock)
      {
        ensureConsistentState();
        List localList = this.mActivities;
        int j = localList.size();
        i = 0;
        if (i < j)
        {
          if (((ActivityResolveInfo)localList.get(i)).resolveInfo == paramResolveInfo) {
            return i;
          }
        }
        else {
          return -1;
        }
      }
      i += 1;
    }
  }
  
  public ResolveInfo getDefaultActivity()
  {
    synchronized (this.mInstanceLock)
    {
      ensureConsistentState();
      if (!this.mActivities.isEmpty())
      {
        ResolveInfo localResolveInfo = ((ActivityResolveInfo)this.mActivities.get(0)).resolveInfo;
        return localResolveInfo;
      }
      return null;
    }
  }
  
  public int getHistoryMaxSize()
  {
    synchronized (this.mInstanceLock)
    {
      int i = this.mHistoryMaxSize;
      return i;
    }
  }
  
  public int getHistorySize()
  {
    synchronized (this.mInstanceLock)
    {
      ensureConsistentState();
      int i = this.mHistoricalRecords.size();
      return i;
    }
  }
  
  public Intent getIntent()
  {
    synchronized (this.mInstanceLock)
    {
      Intent localIntent = this.mIntent;
      return localIntent;
    }
  }
  
  public void setActivitySorter(ActivitySorter paramActivitySorter)
  {
    synchronized (this.mInstanceLock)
    {
      if (this.mActivitySorter == paramActivitySorter) {
        return;
      }
      this.mActivitySorter = paramActivitySorter;
      if (sortActivitiesIfNeeded()) {
        notifyChanged();
      }
      return;
    }
  }
  
  public void setDefaultActivity(int paramInt)
  {
    for (;;)
    {
      synchronized (this.mInstanceLock)
      {
        ensureConsistentState();
        ActivityResolveInfo localActivityResolveInfo1 = (ActivityResolveInfo)this.mActivities.get(paramInt);
        ActivityResolveInfo localActivityResolveInfo2 = (ActivityResolveInfo)this.mActivities.get(0);
        if (localActivityResolveInfo2 != null)
        {
          f = localActivityResolveInfo2.weight - localActivityResolveInfo1.weight + 5.0F;
          addHisoricalRecord(new HistoricalRecord(new ComponentName(localActivityResolveInfo1.resolveInfo.activityInfo.packageName, localActivityResolveInfo1.resolveInfo.activityInfo.name), System.currentTimeMillis(), f));
          return;
        }
      }
      float f = 1.0F;
    }
  }
  
  public void setHistoryMaxSize(int paramInt)
  {
    synchronized (this.mInstanceLock)
    {
      if (this.mHistoryMaxSize == paramInt) {
        return;
      }
      this.mHistoryMaxSize = paramInt;
      pruneExcessiveHistoricalRecordsIfNeeded();
      if (sortActivitiesIfNeeded()) {
        notifyChanged();
      }
      return;
    }
  }
  
  public void setIntent(Intent paramIntent)
  {
    synchronized (this.mInstanceLock)
    {
      if (this.mIntent == paramIntent) {
        return;
      }
      this.mIntent = paramIntent;
      this.mReloadActivities = true;
      ensureConsistentState();
      return;
    }
  }
  
  public void setOnChooseActivityListener(OnChooseActivityListener paramOnChooseActivityListener)
  {
    synchronized (this.mInstanceLock)
    {
      this.mActivityChoserModelPolicy = paramOnChooseActivityListener;
      return;
    }
  }
  
  public static abstract interface ActivityChooserModelClient
  {
    public abstract void setActivityChooserModel(ActivityChooserModel paramActivityChooserModel);
  }
  
  public final class ActivityResolveInfo
    implements Comparable<ActivityResolveInfo>
  {
    public final ResolveInfo resolveInfo;
    public float weight;
    
    public ActivityResolveInfo(ResolveInfo paramResolveInfo)
    {
      this.resolveInfo = paramResolveInfo;
    }
    
    public int compareTo(ActivityResolveInfo paramActivityResolveInfo)
    {
      return Float.floatToIntBits(paramActivityResolveInfo.weight) - Float.floatToIntBits(this.weight);
    }
    
    public boolean equals(Object paramObject)
    {
      if (this == paramObject) {
        return true;
      }
      if (paramObject == null) {
        return false;
      }
      if (getClass() != paramObject.getClass()) {
        return false;
      }
      paramObject = (ActivityResolveInfo)paramObject;
      return Float.floatToIntBits(this.weight) == Float.floatToIntBits(((ActivityResolveInfo)paramObject).weight);
    }
    
    public int hashCode()
    {
      return 31 + Float.floatToIntBits(this.weight);
    }
    
    public String toString()
    {
      StringBuilder localStringBuilder = new StringBuilder();
      localStringBuilder.append("[");
      localStringBuilder.append("resolveInfo:").append(this.resolveInfo.toString());
      localStringBuilder.append("; weight:").append(new BigDecimal(this.weight));
      localStringBuilder.append("]");
      return localStringBuilder.toString();
    }
  }
  
  public static abstract interface ActivitySorter
  {
    public abstract void sort(Intent paramIntent, List<ActivityChooserModel.ActivityResolveInfo> paramList, List<ActivityChooserModel.HistoricalRecord> paramList1);
  }
  
  private final class DefaultSorter
    implements ActivityChooserModel.ActivitySorter
  {
    private static final float WEIGHT_DECAY_COEFFICIENT = 0.95F;
    private final Map<ComponentName, ActivityChooserModel.ActivityResolveInfo> mPackageNameToActivityMap = new HashMap();
    
    private DefaultSorter() {}
    
    public void sort(Intent paramIntent, List<ActivityChooserModel.ActivityResolveInfo> paramList, List<ActivityChooserModel.HistoricalRecord> paramList1)
    {
      paramIntent = this.mPackageNameToActivityMap;
      paramIntent.clear();
      int j = paramList.size();
      int i = 0;
      Object localObject;
      while (i < j)
      {
        localObject = (ActivityChooserModel.ActivityResolveInfo)paramList.get(i);
        ((ActivityChooserModel.ActivityResolveInfo)localObject).weight = 0.0F;
        paramIntent.put(new ComponentName(((ActivityChooserModel.ActivityResolveInfo)localObject).resolveInfo.activityInfo.packageName, ((ActivityChooserModel.ActivityResolveInfo)localObject).resolveInfo.activityInfo.name), localObject);
        i += 1;
      }
      i = paramList1.size();
      float f1 = 1.0F;
      i -= 1;
      while (i >= 0)
      {
        localObject = (ActivityChooserModel.HistoricalRecord)paramList1.get(i);
        ActivityChooserModel.ActivityResolveInfo localActivityResolveInfo = (ActivityChooserModel.ActivityResolveInfo)paramIntent.get(((ActivityChooserModel.HistoricalRecord)localObject).activity);
        float f2 = f1;
        if (localActivityResolveInfo != null)
        {
          localActivityResolveInfo.weight += ((ActivityChooserModel.HistoricalRecord)localObject).weight * f1;
          f2 = f1 * 0.95F;
        }
        i -= 1;
        f1 = f2;
      }
      Collections.sort(paramList);
    }
  }
  
  public static final class HistoricalRecord
  {
    public final ComponentName activity;
    public final long time;
    public final float weight;
    
    public HistoricalRecord(ComponentName paramComponentName, long paramLong, float paramFloat)
    {
      this.activity = paramComponentName;
      this.time = paramLong;
      this.weight = paramFloat;
    }
    
    public HistoricalRecord(String paramString, long paramLong, float paramFloat)
    {
      this(ComponentName.unflattenFromString(paramString), paramLong, paramFloat);
    }
    
    public boolean equals(Object paramObject)
    {
      if (this == paramObject) {
        return true;
      }
      if (paramObject == null) {
        return false;
      }
      if (getClass() != paramObject.getClass()) {
        return false;
      }
      paramObject = (HistoricalRecord)paramObject;
      if (this.activity == null)
      {
        if (((HistoricalRecord)paramObject).activity != null) {
          return false;
        }
      }
      else if (!this.activity.equals(((HistoricalRecord)paramObject).activity)) {
        return false;
      }
      if (this.time != ((HistoricalRecord)paramObject).time) {
        return false;
      }
      return Float.floatToIntBits(this.weight) == Float.floatToIntBits(((HistoricalRecord)paramObject).weight);
    }
    
    public int hashCode()
    {
      if (this.activity == null) {}
      for (int i = 0;; i = this.activity.hashCode()) {
        return 31 * (31 * (31 * 1 + i) + (int)(this.time ^ this.time >>> 32)) + Float.floatToIntBits(this.weight);
      }
    }
    
    public String toString()
    {
      StringBuilder localStringBuilder = new StringBuilder();
      localStringBuilder.append("[");
      localStringBuilder.append("; activity:").append(this.activity);
      localStringBuilder.append("; time:").append(this.time);
      localStringBuilder.append("; weight:").append(new BigDecimal(this.weight));
      localStringBuilder.append("]");
      return localStringBuilder.toString();
    }
  }
  
  public static abstract interface OnChooseActivityListener
  {
    public abstract boolean onChooseActivity(ActivityChooserModel paramActivityChooserModel, Intent paramIntent);
  }
  
  private final class PersistHistoryAsyncTask
    extends AsyncTask<Object, Void, Void>
  {
    private PersistHistoryAsyncTask() {}
    
    /* Error */
    public Void doInBackground(Object... paramVarArgs)
    {
      // Byte code:
      //   0: aload_1
      //   1: iconst_0
      //   2: aaload
      //   3: checkcast 36	java/util/List
      //   6: astore 4
      //   8: aload_1
      //   9: iconst_1
      //   10: aaload
      //   11: checkcast 38	java/lang/String
      //   14: astore 5
      //   16: aload_0
      //   17: getfield 14	android/support/v7/widget/ActivityChooserModel$PersistHistoryAsyncTask:this$0	Landroid/support/v7/widget/ActivityChooserModel;
      //   20: invokestatic 42	android/support/v7/widget/ActivityChooserModel:access$200	(Landroid/support/v7/widget/ActivityChooserModel;)Landroid/content/Context;
      //   23: aload 5
      //   25: iconst_0
      //   26: invokevirtual 48	android/content/Context:openFileOutput	(Ljava/lang/String;I)Ljava/io/FileOutputStream;
      //   29: astore_1
      //   30: invokestatic 54	android/util/Xml:newSerializer	()Lorg/xmlpull/v1/XmlSerializer;
      //   33: astore 5
      //   35: aload 5
      //   37: aload_1
      //   38: aconst_null
      //   39: invokeinterface 60 3 0
      //   44: aload 5
      //   46: ldc 62
      //   48: iconst_1
      //   49: invokestatic 68	java/lang/Boolean:valueOf	(Z)Ljava/lang/Boolean;
      //   52: invokeinterface 72 3 0
      //   57: aload 5
      //   59: aconst_null
      //   60: ldc 74
      //   62: invokeinterface 78 3 0
      //   67: pop
      //   68: aload 4
      //   70: invokeinterface 82 1 0
      //   75: istore_3
      //   76: iconst_0
      //   77: istore_2
      //   78: iload_2
      //   79: iload_3
      //   80: if_icmpge +133 -> 213
      //   83: aload 4
      //   85: iconst_0
      //   86: invokeinterface 86 2 0
      //   91: checkcast 88	android/support/v7/widget/ActivityChooserModel$HistoricalRecord
      //   94: astore 6
      //   96: aload 5
      //   98: aconst_null
      //   99: ldc 90
      //   101: invokeinterface 78 3 0
      //   106: pop
      //   107: aload 5
      //   109: aconst_null
      //   110: ldc 92
      //   112: aload 6
      //   114: getfield 95	android/support/v7/widget/ActivityChooserModel$HistoricalRecord:activity	Landroid/content/ComponentName;
      //   117: invokevirtual 101	android/content/ComponentName:flattenToString	()Ljava/lang/String;
      //   120: invokeinterface 105 4 0
      //   125: pop
      //   126: aload 5
      //   128: aconst_null
      //   129: ldc 107
      //   131: aload 6
      //   133: getfield 110	android/support/v7/widget/ActivityChooserModel$HistoricalRecord:time	J
      //   136: invokestatic 113	java/lang/String:valueOf	(J)Ljava/lang/String;
      //   139: invokeinterface 105 4 0
      //   144: pop
      //   145: aload 5
      //   147: aconst_null
      //   148: ldc 115
      //   150: aload 6
      //   152: getfield 118	android/support/v7/widget/ActivityChooserModel$HistoricalRecord:weight	F
      //   155: invokestatic 121	java/lang/String:valueOf	(F)Ljava/lang/String;
      //   158: invokeinterface 105 4 0
      //   163: pop
      //   164: aload 5
      //   166: aconst_null
      //   167: ldc 90
      //   169: invokeinterface 124 3 0
      //   174: pop
      //   175: iload_2
      //   176: iconst_1
      //   177: iadd
      //   178: istore_2
      //   179: goto -101 -> 78
      //   182: astore_1
      //   183: invokestatic 127	android/support/v7/widget/ActivityChooserModel:access$300	()Ljava/lang/String;
      //   186: new 129	java/lang/StringBuilder
      //   189: dup
      //   190: invokespecial 130	java/lang/StringBuilder:<init>	()V
      //   193: ldc -124
      //   195: invokevirtual 136	java/lang/StringBuilder:append	(Ljava/lang/String;)Ljava/lang/StringBuilder;
      //   198: aload 5
      //   200: invokevirtual 136	java/lang/StringBuilder:append	(Ljava/lang/String;)Ljava/lang/StringBuilder;
      //   203: invokevirtual 139	java/lang/StringBuilder:toString	()Ljava/lang/String;
      //   206: aload_1
      //   207: invokestatic 145	android/util/Log:e	(Ljava/lang/String;Ljava/lang/String;Ljava/lang/Throwable;)I
      //   210: pop
      //   211: aconst_null
      //   212: areturn
      //   213: aload 5
      //   215: aconst_null
      //   216: ldc 74
      //   218: invokeinterface 124 3 0
      //   223: pop
      //   224: aload 5
      //   226: invokeinterface 148 1 0
      //   231: aload_0
      //   232: getfield 14	android/support/v7/widget/ActivityChooserModel$PersistHistoryAsyncTask:this$0	Landroid/support/v7/widget/ActivityChooserModel;
      //   235: iconst_1
      //   236: invokestatic 152	android/support/v7/widget/ActivityChooserModel:access$502	(Landroid/support/v7/widget/ActivityChooserModel;Z)Z
      //   239: pop
      //   240: aload_1
      //   241: ifnull +7 -> 248
      //   244: aload_1
      //   245: invokevirtual 157	java/io/FileOutputStream:close	()V
      //   248: aconst_null
      //   249: areturn
      //   250: astore_1
      //   251: goto -3 -> 248
      //   254: astore 4
      //   256: invokestatic 127	android/support/v7/widget/ActivityChooserModel:access$300	()Ljava/lang/String;
      //   259: new 129	java/lang/StringBuilder
      //   262: dup
      //   263: invokespecial 130	java/lang/StringBuilder:<init>	()V
      //   266: ldc -124
      //   268: invokevirtual 136	java/lang/StringBuilder:append	(Ljava/lang/String;)Ljava/lang/StringBuilder;
      //   271: aload_0
      //   272: getfield 14	android/support/v7/widget/ActivityChooserModel$PersistHistoryAsyncTask:this$0	Landroid/support/v7/widget/ActivityChooserModel;
      //   275: invokestatic 161	android/support/v7/widget/ActivityChooserModel:access$400	(Landroid/support/v7/widget/ActivityChooserModel;)Ljava/lang/String;
      //   278: invokevirtual 136	java/lang/StringBuilder:append	(Ljava/lang/String;)Ljava/lang/StringBuilder;
      //   281: invokevirtual 139	java/lang/StringBuilder:toString	()Ljava/lang/String;
      //   284: aload 4
      //   286: invokestatic 145	android/util/Log:e	(Ljava/lang/String;Ljava/lang/String;Ljava/lang/Throwable;)I
      //   289: pop
      //   290: aload_0
      //   291: getfield 14	android/support/v7/widget/ActivityChooserModel$PersistHistoryAsyncTask:this$0	Landroid/support/v7/widget/ActivityChooserModel;
      //   294: iconst_1
      //   295: invokestatic 152	android/support/v7/widget/ActivityChooserModel:access$502	(Landroid/support/v7/widget/ActivityChooserModel;Z)Z
      //   298: pop
      //   299: aload_1
      //   300: ifnull -52 -> 248
      //   303: aload_1
      //   304: invokevirtual 157	java/io/FileOutputStream:close	()V
      //   307: goto -59 -> 248
      //   310: astore_1
      //   311: goto -63 -> 248
      //   314: astore 4
      //   316: invokestatic 127	android/support/v7/widget/ActivityChooserModel:access$300	()Ljava/lang/String;
      //   319: new 129	java/lang/StringBuilder
      //   322: dup
      //   323: invokespecial 130	java/lang/StringBuilder:<init>	()V
      //   326: ldc -124
      //   328: invokevirtual 136	java/lang/StringBuilder:append	(Ljava/lang/String;)Ljava/lang/StringBuilder;
      //   331: aload_0
      //   332: getfield 14	android/support/v7/widget/ActivityChooserModel$PersistHistoryAsyncTask:this$0	Landroid/support/v7/widget/ActivityChooserModel;
      //   335: invokestatic 161	android/support/v7/widget/ActivityChooserModel:access$400	(Landroid/support/v7/widget/ActivityChooserModel;)Ljava/lang/String;
      //   338: invokevirtual 136	java/lang/StringBuilder:append	(Ljava/lang/String;)Ljava/lang/StringBuilder;
      //   341: invokevirtual 139	java/lang/StringBuilder:toString	()Ljava/lang/String;
      //   344: aload 4
      //   346: invokestatic 145	android/util/Log:e	(Ljava/lang/String;Ljava/lang/String;Ljava/lang/Throwable;)I
      //   349: pop
      //   350: aload_0
      //   351: getfield 14	android/support/v7/widget/ActivityChooserModel$PersistHistoryAsyncTask:this$0	Landroid/support/v7/widget/ActivityChooserModel;
      //   354: iconst_1
      //   355: invokestatic 152	android/support/v7/widget/ActivityChooserModel:access$502	(Landroid/support/v7/widget/ActivityChooserModel;Z)Z
      //   358: pop
      //   359: aload_1
      //   360: ifnull -112 -> 248
      //   363: aload_1
      //   364: invokevirtual 157	java/io/FileOutputStream:close	()V
      //   367: goto -119 -> 248
      //   370: astore_1
      //   371: goto -123 -> 248
      //   374: astore 4
      //   376: invokestatic 127	android/support/v7/widget/ActivityChooserModel:access$300	()Ljava/lang/String;
      //   379: new 129	java/lang/StringBuilder
      //   382: dup
      //   383: invokespecial 130	java/lang/StringBuilder:<init>	()V
      //   386: ldc -124
      //   388: invokevirtual 136	java/lang/StringBuilder:append	(Ljava/lang/String;)Ljava/lang/StringBuilder;
      //   391: aload_0
      //   392: getfield 14	android/support/v7/widget/ActivityChooserModel$PersistHistoryAsyncTask:this$0	Landroid/support/v7/widget/ActivityChooserModel;
      //   395: invokestatic 161	android/support/v7/widget/ActivityChooserModel:access$400	(Landroid/support/v7/widget/ActivityChooserModel;)Ljava/lang/String;
      //   398: invokevirtual 136	java/lang/StringBuilder:append	(Ljava/lang/String;)Ljava/lang/StringBuilder;
      //   401: invokevirtual 139	java/lang/StringBuilder:toString	()Ljava/lang/String;
      //   404: aload 4
      //   406: invokestatic 145	android/util/Log:e	(Ljava/lang/String;Ljava/lang/String;Ljava/lang/Throwable;)I
      //   409: pop
      //   410: aload_0
      //   411: getfield 14	android/support/v7/widget/ActivityChooserModel$PersistHistoryAsyncTask:this$0	Landroid/support/v7/widget/ActivityChooserModel;
      //   414: iconst_1
      //   415: invokestatic 152	android/support/v7/widget/ActivityChooserModel:access$502	(Landroid/support/v7/widget/ActivityChooserModel;Z)Z
      //   418: pop
      //   419: aload_1
      //   420: ifnull -172 -> 248
      //   423: aload_1
      //   424: invokevirtual 157	java/io/FileOutputStream:close	()V
      //   427: goto -179 -> 248
      //   430: astore_1
      //   431: goto -183 -> 248
      //   434: astore 4
      //   436: aload_0
      //   437: getfield 14	android/support/v7/widget/ActivityChooserModel$PersistHistoryAsyncTask:this$0	Landroid/support/v7/widget/ActivityChooserModel;
      //   440: iconst_1
      //   441: invokestatic 152	android/support/v7/widget/ActivityChooserModel:access$502	(Landroid/support/v7/widget/ActivityChooserModel;Z)Z
      //   444: pop
      //   445: aload_1
      //   446: ifnull +7 -> 453
      //   449: aload_1
      //   450: invokevirtual 157	java/io/FileOutputStream:close	()V
      //   453: aload 4
      //   455: athrow
      //   456: astore_1
      //   457: goto -4 -> 453
      // Local variable table:
      //   start	length	slot	name	signature
      //   0	460	0	this	PersistHistoryAsyncTask
      //   0	460	1	paramVarArgs	Object[]
      //   77	102	2	i	int
      //   75	6	3	j	int
      //   6	78	4	localList	List
      //   254	31	4	localIllegalArgumentException	IllegalArgumentException
      //   314	31	4	localIllegalStateException	IllegalStateException
      //   374	31	4	localIOException	java.io.IOException
      //   434	20	4	localObject1	Object
      //   14	211	5	localObject2	Object
      //   94	57	6	localHistoricalRecord	ActivityChooserModel.HistoricalRecord
      // Exception table:
      //   from	to	target	type
      //   16	30	182	java/io/FileNotFoundException
      //   244	248	250	java/io/IOException
      //   35	76	254	java/lang/IllegalArgumentException
      //   83	175	254	java/lang/IllegalArgumentException
      //   213	231	254	java/lang/IllegalArgumentException
      //   303	307	310	java/io/IOException
      //   35	76	314	java/lang/IllegalStateException
      //   83	175	314	java/lang/IllegalStateException
      //   213	231	314	java/lang/IllegalStateException
      //   363	367	370	java/io/IOException
      //   35	76	374	java/io/IOException
      //   83	175	374	java/io/IOException
      //   213	231	374	java/io/IOException
      //   423	427	430	java/io/IOException
      //   35	76	434	finally
      //   83	175	434	finally
      //   213	231	434	finally
      //   256	290	434	finally
      //   316	350	434	finally
      //   376	410	434	finally
      //   449	453	456	java/io/IOException
    }
  }
}


/* Location:              /home/enzo/Documents/hacking/malwares/slocker/classes-dex2jar.jar!/android/support/v7/widget/ActivityChooserModel.class
 * Java compiler version: 6 (50.0)
 * JD-Core Version:       0.7.1
 */